/**
 * Blog Template
 * Copyright (C) 2024
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 */
/**
 * Gestionnaire de blog
 * Ce script gère le chargement dynamique des articles, le filtrage par catégorie,
 * et l'affichage des articles complets
 */

document.addEventListener('DOMContentLoaded', async () => {
    const blogPosts = document.querySelector('.blog-posts');
    const recentPosts = document.querySelector('.recent-posts');
    
    /**
     * Charge les articles depuis l'API
     * @returns {Promise<Array>} Liste des articles
     */
    async function loadPosts() {
        try {
            const response = await fetch('blog.php?api=1');
            const posts = await response.json();
            return posts;
        } catch (error) {
            console.error('Erreur de chargement:', error);
            return [];
        }
    }
    
    /**
     * Crée un élément article HTML
     * @param {Object} post Données de l'article
     * @returns {HTMLElement} Élément article
     */
    function createArticle(post) {
        const article = document.createElement('article');
        article.className = 'post';
        article.id = post.slug;
        article.dataset.category = post.metadata.category;
        
        article.innerHTML = `
            <div class="post-image">
                <img src="${post.metadata.image}" alt="${post.metadata.title}" loading="lazy">
            </div>
            <div class="post-content">
                <h2>${post.metadata.title}</h2>
                <div class="post-meta">
                    <span class="date">${formatDate(post.metadata.date)}</span>
                    <span class="category">${post.metadata.category}</span>
                </div>
                <p>${post.metadata.excerpt}</p>
                <a href="#" class="read-more" data-slug="${post.slug}">Lire la suite</a>
                <div class="post-tags">
                    ${post.metadata.tags.map(tag => `<span>#${tag}</span>`).join('')}
                </div>
            </div>
        `;
        
        return article;
    }
    
    // Formater la date
    function formatDate(dateStr) {
        const options = { year: 'numeric', month: 'long', day: 'numeric' };
        return new Date(dateStr).toLocaleDateString('fr-FR', options);
    }
    
    // Gestion des catégories
    const categoryLinks = document.querySelectorAll('[data-category]');
    categoryLinks.forEach(link => {
        link.addEventListener('click', (e) => {
            e.preventDefault();
            
            categoryLinks.forEach(l => l.classList.remove('active'));
            link.classList.add('active');
            
            const category = link.dataset.category;
            const posts = document.querySelectorAll('.post');
            
            posts.forEach(post => {
                post.style.opacity = '0';
                post.style.transform = 'translateY(20px)';
            });
            
            setTimeout(() => {
                posts.forEach(post => {
                    if (category === 'all' || post.dataset.category === category) {
                        post.style.display = 'block';
                        setTimeout(() => {
                            post.style.opacity = '1';
                            post.style.transform = 'translateY(0)';
                        }, 50);
                    } else {
                        post.style.display = 'none';
                    }
                });
            }, 300);
        });
    });
    
    // Gestion du clic sur "Lire la suite"
    blogPosts.addEventListener('click', async (e) => {
        if (e.target.classList.contains('read-more')) {
            e.preventDefault();
            const slug = e.target.dataset.slug;
            
            try {
                const response = await fetch(`blog.php?api=1&slug=${slug}`);
                const post = await response.json();
                
                // Créer une modal pour afficher l'article complet
                const modal = document.createElement('div');
                modal.className = 'modal';
                modal.innerHTML = `
                    <div class="modal-content">
                        <span class="close">&times;</span>
                        <h1>${post.metadata.title}</h1>
                        <div class="post-meta">
                            <span class="date">${formatDate(post.metadata.date)}</span>
                            <span class="category">${post.metadata.category}</span>
                        </div>
                        <div class="post-content">
                            ${post.content}
                        </div>
                    </div>
                `;
                
                document.body.appendChild(modal);
                
                // Gérer la fermeture de la modal
                modal.querySelector('.close').addEventListener('click', () => {
                    modal.remove();
                });
                
                window.addEventListener('click', (e) => {
                    if (e.target === modal) {
                        modal.remove();
                    }
                });
            } catch (error) {
                console.error('Erreur lors du chargement de l\'article:', error);
            }
        }
    });
    
    // Initialiser les animations
    function initAnimations() {
        const observerOptions = {
            root: null,
            rootMargin: '0px',
            threshold: 0.1
        };
        
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.style.transform = 'scale(1)';
                    entry.target.style.opacity = '1';
                    observer.unobserve(entry.target);
                }
            });
        }, observerOptions);
        
        document.querySelectorAll('.post-image').forEach(img => {
            img.style.transform = 'scale(0.95)';
            img.style.opacity = '0';
            img.style.transition = 'all 0.5s ease-in-out';
            observer.observe(img);
        });
    }
    
    // Initialisation du blog
    const posts = await loadPosts();
    
    // Vider le conteneur
    blogPosts.innerHTML = '';
    recentPosts.innerHTML = '';
    
    // Afficher les articles
    posts.forEach((post, index) => {
        const article = createArticle(post);
        blogPosts.appendChild(article);
        
        // Ajouter aux articles récents
        if (index < 3) {
            const li = document.createElement('li');
            li.innerHTML = `<a href="#${post.slug}">${post.metadata.title}</a>`;
            recentPosts.appendChild(li);
        }
    });
    
    // Réinitialiser les animations
    initAnimations();
});
