<?php
/**
 * Blog Template
 * Copyright (C) 2024
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * API de gestion des articles du blog
 * Ce script gère le traitement des fichiers Markdown et leur conversion en JSON
 * 
 * Format attendu des fichiers Markdown :
 * ---
 * title: Titre de l'article
 * date: YYYY-MM-DD
 * category: catégorie
 * tags: [tag1, tag2]
 * ---
 * Contenu de l'article en Markdown
 */

/**
 * Parse un fichier Markdown et extrait les métadonnées
 * @param string $file Chemin du fichier
 * @return array|null Données de l'article
 */
function parseMarkdownFile($file) {
    $content = file_get_contents($file);
    
    // Extraire les métadonnées
    preg_match('/^---\n(.*?)\n---\n(.*)/s', $content, $matches);
    
    if (count($matches) < 3) {
        return null;
    }
    
    // Parser les métadonnées
    $metadata = [];
    $metaLines = explode("\n", $matches[1]);
    foreach ($metaLines as $line) {
        if (empty($line)) continue;
        
        $parts = explode(':', $line, 2);
        if (count($parts) === 2) {
            $key = trim($parts[0]);
            $value = trim($parts[1]);
            
            // Gérer les tableaux (tags)
            if ($key === 'tags') {
                $value = array_map('trim', explode(',', str_replace(['[', ']', '"'], '', $value)));
            } else {
                $value = trim($value, '"\''); // Enlever les guillemets
            }
            
            $metadata[$key] = $value;
        }
    }
    
    // Parser le contenu Markdown (version simple)
    $content = $matches[2];
    
    // Conversion Markdown basique
    $content = preg_replace('/^# (.*?)$/m', '<h1>$1</h1>', $content);
    $content = preg_replace('/^## (.*?)$/m', '<h2>$1</h2>', $content);
    $content = preg_replace('/^- (.*?)$/m', '<li>$1</li>', $content);
    $content = preg_replace('/\n\n/', '</p><p>', $content);
    
    return [
        'metadata' => $metadata,
        'content' => '<p>' . $content . '</p>',
        'slug' => basename($file, '.md')
    ];
}

try {
    // Gestion des requêtes API
    if (isset($_GET['api'])) {
        header('Content-Type: application/json');
        
        // Récupération d'un article spécifique
        if (isset($_GET['slug'])) {
            $file = __DIR__ . '/posts/' . $_GET['slug'] . '.md';
            if (file_exists($file)) {
                $post = parseMarkdownFile($file);
                echo json_encode($post);
            } else {
                http_response_code(404);
                echo json_encode(['error' => 'Article non trouvé']);
            }
        }
        
        // Récupération de tous les articles
        else {
            $posts = [];
            $files = glob(__DIR__ . '/posts/*.md');
            
            foreach ($files as $file) {
                $post = parseMarkdownFile($file);
                if ($post) {
                    $posts[] = $post;
                }
            }
            
            // Trier par date décroissante
            usort($posts, function($a, $b) {
                return strtotime($b['metadata']['date']) - strtotime($a['metadata']['date']);
            });
            
            echo json_encode($posts);
        }
    }
} catch (Exception $e) {
    // Gestion des erreurs
    http_response_code(500);
    echo json_encode(['error' => $e->getMessage()]);
}
?>
